@@ -15,7 +15,7 @@ use crate::server::Map as ServerMap;
 use crate::theme::Palette;
 use crate::{environment, Theme};
 
-mod buffer;
+pub mod buffer;
 pub mod channel;
 pub mod dashboard;
 mod keys;
@@ -62,7 +62,7 @@ impl Config {
         let dir = environment::config_dir();
 
         if !dir.exists() {
-            std::fs::create_dir(dir.as_path())
+            std::fs::create_dir_all(dir.as_path())
                 .expect("expected permissions to create config folder");
         }
 
@@ -73,7 +73,7 @@ impl Config {
         let dir = Self::config_dir().join("themes");
 
         if !dir.exists() {
-            std::fs::create_dir(dir.as_path())
+            std::fs::create_dir_all(dir.as_path())
                 .expect("expected permissions to create themes folder");
         }
 
