@@ -121,6 +121,7 @@ pub fn view<'a>(
             )
             .map(Message::InputView)
         ]
+        .width(Length::Fill)
     });
 
     let content = match (settings.users.visible, config.buffer.channel.users.position) {
@@ -227,25 +228,20 @@ mod nick_list {
     use crate::widget::Element;
 
     pub fn view(users: &[User]) -> Element<Message> {
-        let column = column(
-            users
-                .iter()
-                .map(|user| {
-                    let content = text(format!(
-                        "{}{}",
-                        user.highest_access_level(),
-                        user.nickname()
-                    ))
-                    .style(if user.is_away() {
-                        theme::Text::Transparent
-                    } else {
-                        theme::Text::Primary
-                    });
+        let column = column(users.iter().map(|user| {
+            let content = text(format!(
+                "{}{}",
+                user.highest_access_level(),
+                user.nickname()
+            ))
+            .style(if user.is_away() {
+                theme::Text::Transparent
+            } else {
+                theme::Text::Primary
+            });
 
-                    user_context::view(content, user.clone())
-                })
-                .collect(),
-        )
+            user_context::view(content, user.clone())
+        }))
         .padding(4)
         .spacing(1);
 
