@@ -83,12 +83,15 @@ fn settings(
 
     iced::Settings {
         default_font: font::MONO.clone().into(),
-        default_text_size,
-        window: window::settings(),
-        exit_on_close_request: false,
+        default_text_size: default_text_size.into(),
+        window: window::Settings {
+            exit_on_close_request: false,
+            ..window::settings()
+        },
         flags: config_load,
         id: None,
         antialiasing: false,
+        fonts: font::load(),
     }
 }
 
@@ -165,7 +168,6 @@ pub enum Message {
     Help(help::Message),
     Welcome(welcome::Message),
     Event(Event),
-    FontsLoaded(Result<(), iced::font::Error>),
     Tick(Instant),
 }
 
@@ -178,10 +180,7 @@ impl Application for Halloy {
     fn new(config_load: Self::Flags) -> (Halloy, Command<Self::Message>) {
         let (halloy, command) = Halloy::load_from_state(config_load);
 
-        (
-            halloy,
-            Command::batch(vec![font::load().map(Message::FontsLoaded), command]),
-        )
+        (halloy, command)
     }
 
     fn title(&self) -> String {
@@ -260,7 +259,7 @@ impl Application for Halloy {
 
                     if is_initial {
                         // Intial is sent when first trying to connect
-                        dashboard.broadcast_connecting(&server);
+                        dashboard.broadcast_connecting(&server, &self.config);
                     } else {
                         let notification = &self.config.notifications.disconnected;
 
@@ -268,7 +267,7 @@ impl Application for Halloy {
                             notification::show("Disconnected", &server, notification.sound());
                         };
 
-                        dashboard.broadcast_disconnected(&server, error);
+                        dashboard.broadcast_disconnected(&server, error, &self.config);
                     }
 
                     Command::none()
@@ -291,7 +290,7 @@ impl Application for Halloy {
                             notification::show("Connected", &server, notification.sound());
                         }
 
-                        dashboard.broadcast_connected(&server);
+                        dashboard.broadcast_connected(&server, &self.config);
                     } else {
                         let notification = &self.config.notifications.reconnected;
 
@@ -299,7 +298,7 @@ impl Application for Halloy {
                             notification::show("Reconnected", &server, notification.sound());
                         }
 
-                        dashboard.broadcast_reconnected(&server);
+                        dashboard.broadcast_reconnected(&server, &self.config);
                     }
 
                     Command::none()
@@ -309,7 +308,7 @@ impl Application for Halloy {
                         return Command::none();
                     };
 
-                    dashboard.broadcast_connection_failed(&server, error);
+                    dashboard.broadcast_connection_failed(&server, error, &self.config);
 
                     Command::none()
                 }
@@ -323,14 +322,14 @@ impl Application for Halloy {
                             match event {
                                 data::client::Event::Single(encoded, our_nick) => {
                                     if let Some(message) =
-                                        data::Message::received(encoded, our_nick)
+                                        data::Message::received(encoded, our_nick, &self.config)
                                     {
                                         dashboard.record_message(&server, message);
                                     }
                                 }
                                 data::client::Event::WithTarget(encoded, our_nick, target) => {
                                     if let Some(message) =
-                                        data::Message::received(encoded, our_nick)
+                                        data::Message::received(encoded, our_nick, &self.config)
                                     {
                                         dashboard
                                             .record_message(&server, message.with_target(target));
@@ -342,7 +341,13 @@ impl Application for Halloy {
                                         comment,
                                         channels,
                                     } => {
-                                        dashboard.broadcast_quit(&server, user, comment, channels);
+                                        dashboard.broadcast_quit(
+                                            &server,
+                                            user,
+                                            comment,
+                                            channels,
+                                            &self.config,
+                                        );
                                     }
                                     data::client::Brodcast::Nickname {
                                         old_user,
@@ -358,6 +363,7 @@ impl Application for Halloy {
                                             new_nick,
                                             ourself,
                                             channels,
+                                            &self.config,
                                         );
                                     }
                                     data::client::Brodcast::Invite {
@@ -372,6 +378,7 @@ impl Application for Halloy {
                                             inviter.to_owned(),
                                             channel,
                                             user_channels,
+                                            &self.config,
                                         );
                                     }
                                 },
@@ -381,7 +388,7 @@ impl Application for Halloy {
                                     notification,
                                 ) => {
                                     if let Some(message) =
-                                        data::Message::received(encoded, our_nick)
+                                        data::Message::received(encoded, our_nick, &self.config)
                                     {
                                         dashboard.record_message(&server, message);
                                     }
@@ -414,18 +421,13 @@ impl Application for Halloy {
                     Command::none()
                 }
             },
-            Message::FontsLoaded(Ok(())) => Command::none(),
-            Message::FontsLoaded(Err(error)) => {
-                log::error!("fonts failed to load: {error:?}");
-                Command::none()
-            }
             Message::Event(event) => {
                 if let Screen::Dashboard(dashboard) = &mut self.screen {
                     dashboard
                         .handle_event(event, &self.clients, &self.config, &mut self.theme)
                         .map(Message::Dashboard)
                 } else if let event::Event::CloseRequested = event {
-                    window::close()
+                    window::close(window::Id::MAIN)
                 } else {
                     Command::none()
                 }
