@@ -1,7 +1,7 @@
 use data::message;
 use data::theme::{randomize_color, Colors};
 use iced::widget::{button, container, pane_grid, rule, scrollable, text, text_input};
-use iced::{application, overlay, Background, Color};
+use iced::{application, overlay, Background, Border, Color};
 
 use crate::widget::selectable_text;
 
@@ -188,25 +188,32 @@ impl container::StyleSheet for Theme {
             },
             Container::PaneBody { selected } => container::Appearance {
                 background: Some(Background::Color(self.colors().background.dark)),
-                border_radius: 4.0.into(),
-                border_width: 1.0,
-                border_color: if *selected {
-                    self.colors().action.base
-                } else {
-                    Color::TRANSPARENT
+                border: Border {
+                    radius: 4.0.into(),
+                    width: 1.0,
+                    color: if *selected {
+                        self.colors().action.base
+                    } else {
+                        Color::TRANSPARENT
+                    },
                 },
                 ..Default::default()
             },
             Container::PaneHeader => container::Appearance {
                 background: Some(Background::Color(self.colors().background.darker)),
-                border_radius: [4.0, 4.0, 0.0, 0.0].into(),
-                border_width: 1.0,
-                border_color: Color::TRANSPARENT,
+                border: Border {
+                    radius: [4.0, 4.0, 0.0, 0.0].into(),
+                    width: 1.0,
+                    color: Color::TRANSPARENT,
+                },
                 ..Default::default()
             },
             Container::Command { selected } if *selected => container::Appearance {
                 background: Some(Background::Color(self.colors().background.darker)),
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Container::Command { .. } => container::Appearance {
@@ -216,18 +223,23 @@ impl container::StyleSheet for Theme {
             Container::Context => container::Appearance {
                 //TODO: Blur background when possible?
                 background: Some(Background::Color(self.colors().background.base)),
-                border_radius: 4.0.into(),
-                border_width: 1.0,
-                border_color: if self.colors().background.is_dark() {
-                    self.colors().background.lighter
-                } else {
-                    self.colors().background.darker
+                border: Border {
+                    radius: 4.0.into(),
+                    width: 1.0,
+                    color: if self.colors().background.is_dark() {
+                        self.colors().background.lighter
+                    } else {
+                        self.colors().background.darker
+                    },
                 },
                 ..Default::default()
             },
             Container::Highlight => container::Appearance {
                 background: Some(Background::Color(self.colors().info.high_alpha)),
-                border_radius: 0.0.into(),
+                border: Border {
+                    radius: 0.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Container::SemiTransparent => container::Appearance {
@@ -267,46 +279,65 @@ impl button::StyleSheet for Theme {
             Button::Default => button::Appearance {
                 background: Some(Background::Color(self.colors().action.high_alpha)),
                 text_color: self.colors().action.base,
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::Secondary => button::Appearance {
                 background: Some(Background::Color(self.colors().text.high_alpha)),
                 text_color: self.colors().text.base,
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::SideMenu { selected } if *selected => button::Appearance {
                 background: Some(Background::Color(self.colors().background.darker)),
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::SideMenu { .. } => button::Appearance {
                 background: None,
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::Pane { selected } if *selected => button::Appearance {
                 background: Some(Background::Color(self.colors().action.med_alpha)),
-                border_color: self.colors().action.low_alpha,
-                border_width: 1.0,
-                border_radius: 3.0.into(),
+                border: Border {
+                    color: self.colors().action.low_alpha,
+                    width: 1.0,
+                    radius: 3.0.into(),
+                },
                 ..Default::default()
             },
             Button::Pane { .. } => button::Appearance {
                 background: Some(Background::Color(self.colors().background.dark)),
-                border_color: if self.colors().background.is_dark() {
-                    self.colors().background.lightest
-                } else {
-                    self.colors().background.darkest
+                border: Border {
+                    color: if self.colors().background.is_dark() {
+                        self.colors().background.lightest
+                    } else {
+                        self.colors().background.darkest
+                    },
+                    width: 1.0,
+                    radius: 3.0.into(),
                 },
-                border_width: 1.0,
-                border_radius: 3.0.into(),
                 ..Default::default()
             },
             Button::Context => button::Appearance {
                 background: Some(Background::Color(Color::TRANSPARENT)),
-                border_radius: 4.0.into(),
+                border: Border {
+                    radius: 4.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::Bare => button::Appearance {
@@ -335,13 +366,19 @@ impl button::StyleSheet for Theme {
             Button::Default => button::Appearance {
                 background: Some(Background::Color(self.colors().action.med_alpha)),
                 text_color: self.colors().action.base,
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::Secondary => button::Appearance {
                 background: Some(Background::Color(self.colors().text.med_alpha)),
                 text_color: self.colors().text.base,
-                border_radius: 3.0.into(),
+                border: Border {
+                    radius: 3.0.into(),
+                    ..Default::default()
+                },
                 ..Default::default()
             },
             Button::SideMenu { selected } if *selected => button::Appearance {
@@ -380,9 +417,12 @@ impl button::StyleSheet for Theme {
                 a: 0.2,
                 ..active.text_color
             },
-            border_color: Color {
-                a: 0.2,
-                ..active.border_color
+            border: Border {
+                color: Color {
+                    a: 0.2,
+                    ..active.border.color
+                },
+                ..Default::default()
             },
             ..active
         }
@@ -403,26 +443,34 @@ impl scrollable::StyleSheet for Theme {
         match style {
             Scrollable::Default => scrollable::Scrollbar {
                 background: Some(Background::Color(self.colors().background.darker)),
-                border_radius: 8.0.into(),
-                border_width: 1.0,
-                border_color: Color::TRANSPARENT,
+                border: Border {
+                    radius: 8.0.into(),
+                    width: 1.0,
+                    color: Color::TRANSPARENT,
+                },
                 scroller: scrollable::Scroller {
                     color: self.colors().background.darkest,
-                    border_radius: 8.0.into(),
-                    border_width: 0.0,
-                    border_color: Color::TRANSPARENT,
+                    border: Border {
+                        radius: 8.0.into(),
+                        width: 0.0,
+                        color: Color::TRANSPARENT,
+                    },
                 },
             },
             Scrollable::Hidden => scrollable::Scrollbar {
                 background: Some(Background::Color(Color::TRANSPARENT)),
-                border_radius: 8.0.into(),
-                border_width: 1.0,
-                border_color: Color::TRANSPARENT,
+                border: Border {
+                    radius: 8.0.into(),
+                    width: 1.0,
+                    color: Color::TRANSPARENT,
+                },
                 scroller: scrollable::Scroller {
                     color: Color::TRANSPARENT,
-                    border_radius: 8.0.into(),
-                    border_width: 0.0,
-                    border_color: Color::TRANSPARENT,
+                    border: Border {
+                        radius: 8.0.into(),
+                        width: 0.0,
+                        color: Color::TRANSPARENT,
+                    },
                 },
             },
         }
@@ -454,9 +502,11 @@ impl pane_grid::StyleSheet for Theme {
         match style {
             PaneGrid::Default => pane_grid::Appearance {
                 background: Background::Color(self.colors().action.high_alpha),
-                border_width: 1.0,
-                border_color: self.colors().action.base,
-                border_radius: 4.0.into(),
+                border: Border {
+                    width: 1.0,
+                    color: self.colors().action.base,
+                    radius: 4.0.into(),
+                },
             },
         }
     }
@@ -494,15 +544,20 @@ impl text_input::StyleSheet for Theme {
         match style {
             TextInput::Default => text_input::Appearance {
                 background: Background::Color(self.colors().background.darker),
-                border_radius: 4.0.into(),
-                border_width: 0.0,
-                border_color: Color::TRANSPARENT,
-                // XXX Not currently displayed in application.
+                border: Border {
+                    radius: 4.0.into(),
+                    width: 0.0,
+                    color: Color::TRANSPARENT,
+                    // XXX Not currently displayed in application.
+                },
                 icon_color: self.colors().info.base,
             },
             TextInput::Error => text_input::Appearance {
-                border_width: 1.0,
-                border_color: self.colors().error.base,
+                border: Border {
+                    width: 1.0,
+                    color: self.colors().error.base,
+                    ..Default::default()
+                },
                 ..self.active(&TextInput::Default)
             },
         }
@@ -544,10 +599,12 @@ impl text_input::StyleSheet for Theme {
         match style {
             TextInput::Default | TextInput::Error => text_input::Appearance {
                 background: Background::Color(self.colors().background.light),
-                border_radius: 0.0.into(),
-                border_width: 0.0,
-                border_color: Color::TRANSPARENT,
-                // XXX Not currently displayed in application.
+                border: Border {
+                    radius: 0.0.into(),
+                    width: 0.0,
+                    color: Color::TRANSPARENT,
+                    // XXX Not currently displayed in application.
+                },
                 icon_color: self.colors().info.base,
             },
         }
@@ -583,21 +640,25 @@ impl overlay::menu::StyleSheet for Theme {
             Menu::Default => overlay::menu::Appearance {
                 text_color: self.colors().text.base,
                 background: Background::Color(self.colors().background.base),
-                border_width: 1.0,
-                border_radius: 4.0.into(),
-                border_color: self.colors().action.base,
+                border: Border {
+                    width: 1.0,
+                    radius: 4.0.into(),
+                    color: self.colors().action.base,
+                },
                 selected_text_color: self.colors().text.high_alpha,
                 selected_background: Background::Color(self.colors().background.high_alpha),
             },
             Menu::ComboBox => overlay::menu::Appearance {
                 text_color: self.colors().text.base,
                 background: Background::Color(self.colors().background.base),
-                border_width: 1.0,
-                border_radius: 4.0.into(),
-                border_color: if self.colors().background.is_dark() {
-                    self.colors().background.lighter
-                } else {
-                    self.colors().background.darker
+                border: Border {
+                    width: 1.0,
+                    radius: 4.0.into(),
+                    color: if self.colors().background.is_dark() {
+                        self.colors().background.lighter
+                    } else {
+                        self.colors().background.darker
+                    },
                 },
                 selected_text_color: self.colors().text.base,
                 selected_background: Background::Color(self.colors().background.dark),
